@@ -1,6 +1,9 @@
 <?php
 /**
- * The Horde_Compress_zip class allows ZIP files to be created and read.
+ * Copyright 2000-2017 Horde LLC (http://www.horde.org/)
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * The ZIP compression code is partially based on code from:
  *   Eric Mueller <eric@themepark.com>
@@ -12,10 +15,7 @@
  * The ZIP compression date code is partially based on code from
  *   Peter Listiak <mlady@users.sourceforge.net>
  *
- * Copyright 2000-2016 Horde LLC (http://www.horde.org/)
- *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.horde.org/licenses/lgpl21.
+ * Official ZIP file format: https://support.pkware.com/display/PKZIP/APPNOTE
  *
  * @author   Chuck Hagenbuch <chuck@horde.org>
  * @author   Michael Cochrane <mike@graftonhall.co.nz>
@@ -24,19 +24,47 @@
  * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package  Compress
  */
+
+/**
+ * The Horde_Compress_zip class allows ZIP files to be created and read.
+ *
+ * @author    Chuck Hagenbuch <chuck@horde.org>
+ * @author    Michael Cochrane <mike@graftonhall.co.nz>
+ * @author    Michael Slusarz <slusarz@horde.org>
+ * @category  Horde
+ * @copyright 2000-2017 Horde LLC
+ * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
+ * @package   Compress
+ */
 class Horde_Compress_Zip extends Horde_Compress_Base
 {
-    /* Constants used with decompress(). */
+    /**
+     * Return file list.
+     *
+     * @see decompress().
+     */
     const ZIP_LIST = 1;
+
+    /**
+     * Return file data.
+     *
+     * @see decompress().
+     */
     const ZIP_DATA = 2;
 
-    /* Beginning of central directory record. */
+    /**
+     * Beginning of central directory record.
+     */
     const CTRL_DIR_HEADER = "\x50\x4b\x01\x02";
 
-    /* End of central directory record. */
+    /**
+     * End of central directory record.
+     */
     const CTRL_DIR_END = "\x50\x4b\x05\x06\x00\x00\x00\x00";
 
-    /* Beginning of file contents. */
+    /**
+     * Beginning of file contents.
+     */
     const FILE_HEADER = "\x50\x4b\x03\x04";
 
     /**
@@ -90,28 +118,31 @@ class Horde_Compress_Zip extends Horde_Compress_Base
      *
      * @return mixed  The ZIP file as either a string or a stream resource.
      */
-    public function compress($data, $params = array())
+    public function compress($data, array $params = array())
     {
         if (!Horde_Util::extensionExists('zlib')) {
-            throw new Horde_Compress_Exception(Horde_Compress_Translation::t("This server can't compress zip files."));
+            throw new Horde_Compress_Exception(
+                Horde_Compress_Translation::t(
+                    "This server can't compress zip files."
+                )
+            );
         }
 
         $this->_ctrldir = array();
         $this->_tmp = fopen('php://temp', 'r+');
 
-        reset($data);
-        while (list(, $val) = each($data)) {
+        foreach ($data as $val) {
             $this->_addToZipFile($val);
         }
 
-        /* Creates the ZIP file.
-         * Official ZIP file format: http://www.pkware.com/appnote.txt */
+        /* Create the ZIP file. */
         $dir = implode('', $this->_ctrldir);
 
         fseek($this->_tmp, 0, SEEK_END);
         $offset = ftell($this->_tmp);
 
-        fwrite($this->_tmp,
+        fwrite(
+            $this->_tmp,
             $dir . self::CTRL_DIR_END .
             /* Total # of entries "on this disk". */
             pack('v', count($this->_ctrldir)) .
@@ -165,7 +196,9 @@ class Horde_Compress_Zip extends Horde_Compress_Base
                 return $this->_getZipInfo($data);
 
             case self::ZIP_DATA:
-                return $this->_getZipData($data, $params['info'], $params['key']);
+                return $this->_getZipData(
+                    $data, $params['info'], $params['key']
+                );
             }
         }
     }
@@ -188,12 +221,19 @@ class Horde_Compress_Zip extends Horde_Compress_Base
 
         do {
             if (strlen($data) < $fhStart + 31) {
-                throw new Horde_Compress_Exception(Horde_Compress_Translation::t("Invalid ZIP data"));
+                throw new Horde_Compress_Exception(
+                    Horde_Compress_Translation::t("Invalid ZIP data")
+                );
             }
-            $info = unpack('vMethod/VTime/VCRC32/VCompressed/VUncompressed/vLength', substr($data, $fhStart + 10, 20));
+            $info = unpack(
+                'vMethod/VTime/VCRC32/VCompressed/VUncompressed/vLength',
+                substr($data, $fhStart + 10, 20)
+            );
 
             if (!isset($this->_methods[$info['Method']])) {
-                throw new Horde_Compress_Exception(Horde_Compress_Translation::t("Invalid ZIP data"));
+                throw new Horde_Compress_Exception(
+                    Horde_Compress_Translation::t("Invalid ZIP data")
+                );
             }
 
             $name = substr($data, $fhStart + 46, $info['Length']);
@@ -215,16 +255,23 @@ class Horde_Compress_Zip extends Horde_Compress_Base
                 mktime((($info['Time'] >> 11) & 0x1f),
                        (($info['Time'] >> 5) & 0x3f),
                        (($info['Time'] << 1) & 0x3e),
-                       (($info['Time'] >> 21) & 0x07),
+                       (($info['Time'] >> 21) & 0x0f),
                        (($info['Time'] >> 16) & 0x1f),
                        ((($info['Time'] >> 25) & 0x7f) + 1980));
 
             if (strlen($data) < $fhStart + 43) {
-                throw new Horde_Compress_Exception(Horde_Compress_Translation::t("Invalid ZIP data"));
+                throw new Horde_Compress_Exception(
+                    Horde_Compress_Translation::t("Invalid ZIP data")
+                );
             }
-            $info = unpack('vInternal/VExternal', substr($data, $fhStart + 36, 6));
+            $info = unpack(
+                'vInternal/VExternal',
+                substr($data, $fhStart + 36, 6)
+            );
 
-            $entries[$name]['type'] = ($info['Internal'] & 0x01) ? 'text' : 'binary';
+            $entries[$name]['type'] = ($info['Internal'] & 0x01)
+                ? 'text'
+                : 'binary';
             $entries[$name]['attr'] =
                 (($info['External'] & 0x10) ? 'D' : '-') .
                 (($info['External'] & 0x20) ? 'A' : '-') .
@@ -240,12 +287,18 @@ class Horde_Compress_Zip extends Horde_Compress_Base
 
         do {
             if ($data_len < $fhStart + 34) {
-                throw new Horde_Compress_Exception(Horde_Compress_Translation::t("Invalid ZIP data"));
+                throw new Horde_Compress_Exception(
+                    Horde_Compress_Translation::t("Invalid ZIP data")
+                );
             }
-            $info = unpack('vMethod/VTime/VCRC32/VCompressed/VUncompressed/vLength/vExtraLength', substr($data, $fhStart + 8, 25));
+            $info = unpack(
+                'vMethod/VTime/VCRC32/VCompressed/VUncompressed/vLength/vExtraLength',
+                substr($data, $fhStart + 8, 25)
+            );
             $name = substr($data, $fhStart + 30, $info['Length']);
             if (isset($entries[$name])) {
-                $entries[$name]['_dataStart'] = $fhStart + 30 + $info['Length'] + $info['ExtraLength'];
+                $entries[$name]['_dataStart'] = $fhStart + 30
+                    + $info['Length'] + $info['ExtraLength'];
             }
         } while ($data_len > $fhStart + 30 + $info['Length'] &&
                  ($fhStart = strpos($data, self::FILE_HEADER, $fhStart + 30 + $info['Length'])) !== false);
@@ -268,10 +321,14 @@ class Horde_Compress_Zip extends Horde_Compress_Base
             Horde_Util::extensionExists('zlib')) {
             /* If the file has been deflated, and zlib is installed,
                then inflate the data again. */
-            return @gzinflate(substr($data, $info[$key]['_dataStart'], $info[$key]['csize']));
+            return @gzinflate(
+                substr($data, $info[$key]['_dataStart'], $info[$key]['csize'])
+            );
         } elseif ($info[$key]['_method'] == 0x0) {
             /* Files that aren't compressed. */
-            return substr($data, $info[$key]['_dataStart'], $info[$key]['csize']);
+            return substr(
+                $data, $info[$key]['_dataStart'], $info[$key]['csize']
+            );
         }
 
         return '';
@@ -290,9 +347,8 @@ class Horde_Compress_Zip extends Horde_Compress_Base
     }
 
     /**
-     * Converts a UNIX timestamp to a 4-byte DOS date and time format
-     * (date in high 2-bytes, time in low 2-bytes allowing magnitude
-     * comparison).
+     * Converts a UNIX timestamp to a 4-byte DOS date and time format (date in
+     * high 2-bytes, time in low 2-bytes allowing magnitude comparison).
      *
      * @param integer $unixtime  The current UNIX timestamp.
      *
@@ -332,7 +388,7 @@ class Horde_Compress_Zip extends Horde_Compress_Base
         $ftime = (isset($file['time'])) ? $file['time'] : null;
 
         /* Get the hex time. */
-        $dtime    = dechex($this->_unix2DosTime($ftime));
+        $dtime    = sprintf('%08s', dechex($this->_unix2DosTime($ftime)));
         $hexdtime = chr(hexdec($dtime[6] . $dtime[7])) .
                     chr(hexdec($dtime[4] . $dtime[5])) .
                     chr(hexdec($dtime[2] . $dtime[3])) .
@@ -343,9 +399,20 @@ class Horde_Compress_Zip extends Horde_Compress_Base
             $zdata = fopen('php://temp', 'r+');
 
             $params = new stdClass;
-            stream_filter_register('horde_compress_filter_crc32', 'Horde_Stream_Filter_Crc32');
-            $filter = stream_filter_prepend($file['data'], 'horde_compress_filter_crc32', STREAM_FILTER_READ, $params);
-            $filter2 = stream_filter_append($zdata, 'zlib.deflate', STREAM_FILTER_WRITE);
+            stream_filter_register(
+                'horde_compress_filter_crc32', 'Horde_Stream_Filter_Crc32'
+            );
+            $filter = stream_filter_prepend(
+                $file['data'],
+                'horde_compress_filter_crc32',
+                STREAM_FILTER_READ,
+                $params
+            );
+            $filter2 = stream_filter_append(
+                $zdata,
+                'zlib.deflate',
+                STREAM_FILTER_WRITE
+            );
 
             rewind($file['data']);
             stream_copy_to_stream($file['data'], $zdata);
@@ -405,8 +472,7 @@ class Horde_Compress_Zip extends Horde_Compress_Base
             pack('v', 0) .            /* Internal file attributes. */
             pack('V', 32) .           /* External file attributes -
                                        * 'archive' bit set. */
-            pack('V', $old_offset) .  /* Relative offset of local
-                                       * header. */
+            pack('V', $old_offset) .  /* Relative offset of local header. */
             $name;                    /* File name. */
     }
 
